@@ -37,7 +37,7 @@ sub main::HELP_MESSAGE()
     {
         print("\tchacha20-ietf chacha20-ietf-poly1305\n");
     }
-    print("\trabbit\n");
+#    print("\trabbit\n");
     print("\trc4-md5\n");
     print("\trc6-128-cfb rc6-128-ctr rc6-128-ofb\n");
     print("\trc6-192-cfb rc6-192-ctr rc6-192-ofb\n");
@@ -134,7 +134,6 @@ Usage: ssclient.pl -s SERVER_ADDR -p SERVER_PORT [-b LOCAL_ADDR]
 	camellia-192-cfb camellia-192-ctr camellia-192-ofb
 	camellia-256-cfb camellia-256-ctr camellia-256-ofb
 	chacha20-ietf chacha20-ietf-poly1305
-	rabbit
 	rc6-128-cfb rc6-128-ctr rc6-128-ofb
 	rc6-192-cfb rc6-192-ctr rc6-192-ofb
 	rc6-256-cfb rc6-256-ctr rc6-256-ofb
@@ -166,7 +165,6 @@ SOCKS Protocol Version 5 (RFC 1928 ).
 	camellia-192-cfb camellia-192-ctr camellia-192-ofb
 	camellia-256-cfb camellia-256-ctr camellia-256-ofb
 	chacha20-ietf chacha20-ietf-poly1305
-	rabbit
 	rc6-128-cfb rc6-128-ctr rc6-128-ofb
 	rc6-192-cfb rc6-192-ctr rc6-192-ofb
 	rc6-256-cfb rc6-256-ctr rc6-256-ofb
