@@ -184,7 +184,7 @@ sub _initialize_cipher($$)
         {
             $_key = _EVP_BytesToKey( $_ciphers{$_method}->[2], $_ciphers{$_method}->[3], '', $_password, 1 );
 #                $_iv = makerandom_octet( Length => $_ciphers{$_method}->[3] );
-            $_iv = Crypt::OpenSSL::Random::random_bytes($_ciphers{$_method}->[3]);
+            $_iv = random_bytes($_ciphers{$_method}->[3]);
             my $encrypt_rc4_key;
                 my $md = Digest::MD5->new();
                 $md->add($_key . $_iv);
@@ -215,7 +215,7 @@ sub _initialize_cipher($$)
             {
                 $_key = _EVP_BytesToKey( $_ciphers{$_method}->[2], $_ciphers{$_method}->[3], '', $_password, 1 );
 #                $_iv = makerandom_octet( Length => $_ciphers{$_method}->[3] );
-                $_iv = Crypt::OpenSSL::Random::random_bytes($_ciphers{$_method}->[3]);
+                $_iv = random_bytes($_ciphers{$_method}->[3]);
                 $_encryptor = Crypt::Mode::CFB->new($_ciphers{$_method}->[0]);
                 $_decryptor = Crypt::Mode::CFB->new($_ciphers{$_method}->[0]);
             }
@@ -223,7 +223,7 @@ sub _initialize_cipher($$)
             {
                 $_key = _EVP_BytesToKey( $_ciphers{$_method}->[2], $_ciphers{$_method}->[3], '', $_password, 1 );
 #                $_iv = makerandom_octet( Length => $_ciphers{$_method}->[3] ); 
-                $_iv = Crypt::OpenSSL::Random::random_bytes($_ciphers{$_method}->[3]);
+                $_iv = random_bytes($_ciphers{$_method}->[3]);
                 $_encryptor = Crypt::Mode::CTR->new($_ciphers{$_method}->[0]);
                 $_decryptor = Crypt::Mode::CTR->new($_ciphers{$_method}->[0]);
             }
@@ -231,7 +231,7 @@ sub _initialize_cipher($$)
             {
                 $_key = _EVP_BytesToKey( $_ciphers{$_method}->[2], $_ciphers{$_method}->[3], '', $_password, 1 );
 #                $_iv = makerandom_octet( Length => $_ciphers{$_method}->[3] ); 
-                $_iv = Crypt::OpenSSL::Random::random_bytes($_ciphers{$_method}->[3]);
+                $_iv = random_bytes($_ciphers{$_method}->[3]);
                 $_encryptor = Crypt::Mode::OFB->new($_ciphers{$_method}->[0]);
                 $_decryptor = Crypt::Mode::OFB->new($_ciphers{$_method}->[0]);
             }
@@ -242,7 +242,7 @@ sub _initialize_cipher($$)
 
         $_key = _EVP_BytesToKey(16, 16, '', $_password, 1 );
 #        $_iv = makerandom_octet( Length => 16 );
-        $_iv = Crypt::OpenSSL::Random::random_bytes($_ciphers{$_method}->[3]);
+        $_iv = random_bytes($_ciphers{$_method}->[3]);
         $_encryptor = Crypt::Spritz::Cipher->new($_key, $_iv);
     }
     
