@@ -11,7 +11,6 @@
     use AnyEvent::Socket;
     use Carp;
     use Config;
-    use Crypt::KeyDerivation;
     use Crypt::KeyDerivation qw(hkdf);
     BEGIN 
     {
@@ -710,7 +709,7 @@ Version 0.9.2
     
 =head1 DESCRIPTION
 
-1. A total of 35 encryption methods are supported:
+1. A total of 34 encryption methods are supported:
 
 	aes-128-cfb aes-128-ctr aes-128-gcm aes-128-ofb
 	aes-192-cfb aes-192-ctr aes-192-gcm aes-192-ofb
@@ -719,7 +718,6 @@ Version 0.9.2
 	camellia-192-cfb camellia-192-ctr camellia-192-ofb
 	camellia-256-cfb camellia-256-ctr camellia-256-ofb
 	chacha20-ietf chacha20-ietf-poly1305
-	rabbit
 	rc4-md5
 	rc6-128-cfb rc6-128-ctr rc6-128-ofb
 	rc6-192-cfb rc6-192-ctr rc6-192-ofb
